@@ -2,7 +2,7 @@
 
 # import apis into api package
 from ai_server_connector.api.accesses_api import AccessesApi
-from ai_server_connector.api.ai_assistant_api_api import AiAssistantApiApi
+from ai_server_connector.api.ai_api_api import AiApiApi
 from ai_server_connector.api.assistants_api import AssistantsApi
 from ai_server_connector.api.default_api import DefaultApi
 
